==> ziproxy-2.1.1.tar.bz2: ziproxy-2.1.1/src/cfgfile.h <==
/* cfgfile.h
 * Part of ziproxy package.
 * 
 * Copyright (c)2003-2004 Juraj Variny<variny@naex.sk>
 * Copyright (c)2005-2006 Daniel Mealha Cabrita
 *
 * Released subject to GNU General Public License.
 * 
 * Configuration file parsing functions.
 */

#include <confuse.h>

//To stop multiple inclusions.
#ifndef SRC_CFGFILE_H
#define SRC_CFGFILE_H

extern int Port, NextPort, NetdTimeout, ZTimeout, MaxSize, PreemptNameResMax, MinTextStream;

extern int ImageQ[4];
#define ThumbQ (ImageQ[0])
#define SmallQ (ImageQ[1])
#define MedQ (ImageQ[2])
#define LargeQ (ImageQ[3])

extern float JP2Rate[4];
#define ThumbRate (JP2Rate[0])
#define SmallRate (JP2Rate[1])
#define MedRate (JP2Rate[2])
#define LargeRate (JP2Rate[3])


#ifdef CONFUSEv2
extern cfg_bool_t MSIETest, DoGzip, UseContentLength, ModifySuffixes, AllowLookCh, ProcessJPG, ProcessPNG, ProcessGIF, PreemptNameRes, PreemptNameResBC, TransparentProxy, ProcessHTML, ProcessCSS, ProcessJS, ProcessHTML_CSS, ProcessHTML_JS, ProcessHTML_tags, ProcessHTML_text, ProcessHTML_PRE, ProcessHTML_NoComments;
#else
extern cfgbool_t MSIETest, DoGzip, UseContentLength, ModifySuffixes, AllowLookCh, ProcessJPG, ProcessPNG, ProcessGIF, PreemptNameRes, PreemptNameResBC, TransparentProxy, ProcessHTML, ProcessCSS, ProcessJS, ProcessHTML_CSS, ProcessHTML_JS, ProcessHTML_tags, ProcessHTML_text, ProcessHTML_PRE, ProcessHTML_NoComments;
#endif
extern char *WhereZiproxy, *ServHost, *ServUrl, *OnlyFrom, *LogFileName, *NextProxy;
extern char **LogPipe, **Compressible;
extern char *CustomError400, *CustomError404, *CustomError408, *CustomError500, *CustomError503;
extern char *AccessLogFileName;
extern char *PasswdFile;
extern char **PasswdEntries;
extern unsigned long PasswdNumEntries;

extern int ReadCfgFile(char * cfg_file);
extern int ReadPasswdFile(char * pswd_file);

#ifndef DefaultCfgLocation
extern char DefaultCfgLocation[];
#endif

extern int getRateQuality(int width, int height, int *quality, float *rate);

#endif //SRC_CFGFILE_H

==> ziproxy-2.2.2.tar.bz2: ziproxy-2.2.2/src/cfgfile.h <==
/* cfgfile.h
 * Part of ziproxy package.
 * 
 * Copyright (c)2003-2004 Juraj Variny<variny@naex.sk>
 * Copyright (c)2005-2006 Daniel Mealha Cabrita
 *
 * Released subject to GNU General Public License.
 * 
 * Configuration file parsing functions.
 */

#include <confuse.h>

//To stop multiple inclusions.
#ifndef SRC_CFGFILE_H
#define SRC_CFGFILE_H

extern int Port, NextPort, NetdTimeout, ZTimeout, MaxSize, PreemptNameResMax, MinTextStream;

extern int ImageQ[4];
#define ThumbQ (ImageQ[0])
#define SmallQ (ImageQ[1])
#define MedQ (ImageQ[2])
#define LargeQ (ImageQ[3])

extern float JP2Rate[4];
#define ThumbRate (JP2Rate[0])
#define SmallRate (JP2Rate[1])
#define MedRate (JP2Rate[2])
#define LargeRate (JP2Rate[3])


#ifdef CONFUSEv2
extern cfg_bool_t MSIETest, DoGzip, UseContentLength, ModifySuffixes, AllowLookCh, ProcessJPG, ProcessPNG, ProcessGIF, PreemptNameRes, PreemptNameResBC, TransparentProxy, ConventionalProxy, ProcessHTML, ProcessCSS, ProcessJS, ProcessHTML_CSS, ProcessHTML_JS, ProcessHTML_tags, ProcessHTML_text, ProcessHTML_PRE, ProcessHTML_NoComments;
#else
extern cfgbool_t MSIETest, DoGzip, UseContentLength, ModifySuffixes, AllowLookCh, ProcessJPG, ProcessPNG, ProcessGIF, PreemptNameRes, PreemptNameResBC, TransparentProxy, ConventionalProxy, ProcessHTML, ProcessCSS, ProcessJS, ProcessHTML_CSS, ProcessHTML_JS, ProcessHTML_tags, ProcessHTML_text, ProcessHTML_PRE, ProcessHTML_NoComments;
#endif
extern char *WhereZiproxy, *ServHost, *ServUrl, *OnlyFrom, *LogFileName, *NextProxy;
extern char **LogPipe, **Compressible;
extern char *CustomError400, *CustomError404, *CustomError408, *CustomError500, *CustomError503;
extern char *Address;
extern char *AccessLogFileName;
extern char *PasswdFile;
extern char **PasswdEntries;
extern unsigned long PasswdNumEntries;

extern int ReadCfgFile(char * cfg_file);
extern int ReadPasswdFile(char * pswd_file);

#ifndef DefaultCfgLocation
extern char DefaultCfgLocation[];
#endif

extern int getRateQuality(int width, int height, int *quality, float *rate);

#endif //SRC_CFGFILE_H
